'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var React = require('react');
var PropTypes = require('prop-types');
var TopologyType = require('../models/topology-type');

var BASE_CLASS = 'topology';

/**
 * Topology types to class name mappings.
 */
var TOPOLOGY_TYPES = {
  'Single': 'single',
  'ReplicaSetNoPrimary': 'replica-set',
  'ReplicaSetWithPrimary': 'replica-set',
  'Sharded': 'cluster',
  'Unknown': 'unknown'
};

/**
 * Server types to class name mappings.
 */
var SERVER_TYPES = {
  'Standalone': 'primary',
  'Mongos': 'primary',
  'PossiblePrimary': 'primary',
  'RSPrimary': 'primary',
  'RSSecondary': 'secondary',
  'RSArbiter': 'arbiter',
  'RSOther': 'nostate',
  'RSGhost': 'nostate',
  'Unknown': 'nostate'
};

/**
 * <i class="mms-icon-leaf"> For version.
 */

var DeploymentAwarenessComponent = function (_React$Component) {
  _inherits(DeploymentAwarenessComponent, _React$Component);

  function DeploymentAwarenessComponent() {
    _classCallCheck(this, DeploymentAwarenessComponent);

    return _possibleConstructorReturn(this, (DeploymentAwarenessComponent.__proto__ || Object.getPrototypeOf(DeploymentAwarenessComponent)).apply(this, arguments));
  }

  _createClass(DeploymentAwarenessComponent, [{
    key: 'renderServers',


    /**
     * Render the servers that are connected to.
     *
     * @returns {React.Component} The rendered component.
     */
    value: function renderServers() {
      return this.props.servers.map(function (server, i) {
        return React.createElement(
          'tr',
          { key: i },
          React.createElement(
            'td',
            { className: 'topology-servers-type' },
            React.createElement('i', { className: 'mms-icon-' + SERVER_TYPES[server.type] })
          ),
          React.createElement(
            'td',
            null,
            server.address
          )
        );
      });
    }

    /**
     * Render the replica set name.
     *
     * @returns {React.Component} The rendered component.
     */

  }, {
    key: 'renderSetName',
    value: function renderSetName() {
      if (this.props.setName) {
        return React.createElement(
          'span',
          { className: 'topology-type-set-name' },
          '(',
          this.props.setName,
          ')'
        );
      }
    }
  }, {
    key: 'renderTopologyType',
    value: function renderTopologyType() {
      return React.createElement(
        'div',
        { className: 'topology-type-name' },
        React.createElement('i', { className: 'mms-icon-' + TOPOLOGY_TYPES[this.props.topologyType] }),
        TopologyType.humanize(this.props.topologyType)
      );
    }

    /**
     * Render the name of the deployment.
     *
     * @returns {String} The name.
     */

  }, {
    key: 'renderName',
    value: function renderName() {
      if (this.props.setName) {
        return this.props.setName;
      } else if (this.props.topologyType === TopologyType.SINGLE) {
        return this.props.servers[0].type;
      }
      return this.props.topologyType;
    }
  }, {
    key: 'renderNodes',
    value: function renderNodes() {
      var length = this.props.servers.length;
      return length + ' Node' + (length === 1 ? '' : 's');
    }

    /**
     * Render DeploymentAwareness component.
     *
     * @returns {React.Component} The rendered component.
     */

  }, {
    key: 'render',
    value: function render() {
      return React.createElement(
        'div',
        { className: BASE_CLASS },
        React.createElement('div', { className: 'action-bar' }),
        React.createElement(
          'div',
          { className: 'topology-name' },
          this.renderName()
        ),
        React.createElement(
          'div',
          { className: 'topology-type' },
          this.renderTopologyType()
        ),
        React.createElement(
          'div',
          { className: 'topology-server-count' },
          this.renderNodes()
        ),
        React.createElement(
          'div',
          { className: 'topology-servers' },
          React.createElement(
            'table',
            null,
            this.renderServers()
          )
        )
      );
    }
  }]);

  return DeploymentAwarenessComponent;
}(React.Component);

DeploymentAwarenessComponent.propTypes = {
  servers: PropTypes.array,
  setName: PropTypes.string,
  topologyType: PropTypes.string.isRequired
};

DeploymentAwarenessComponent.displayName = 'DeploymentAwarenessComponent';

module.exports = DeploymentAwarenessComponent;